@@ -145,11 +145,6 @@ class OpenCTIApiClient:
             )
 
     def set_applicant_id_header(self, applicant_id):
-        """set the request header with the specified token
-
-        :param applicant_id: OpenCTI caller id
-        :type applicant_id: str
-        """
         self.request_headers["opencti-applicant-id"] = applicant_id
 
     def set_retry_number(self, retry_number):
@@ -346,7 +341,6 @@ class OpenCTIApiClient:
                 logsWorkerConfig {
                     elasticsearch_url
                     elasticsearch_index
-                    rabbitmq_url
                 }
             }
         """
@@ -531,7 +525,10 @@ class OpenCTIApiClient:
              """
             if data is None:
                 data = open(file_name, "rb")
-                mime_type = magic.from_file(file_name, mime=True)
+                if file_name.endswith(".json"):
+                    mime_type = "application/json"
+                else:
+                    mime_type = magic.from_file(file_name, mime=True)
 
             return self.query(query, {"file": (File(file_name, data, mime_type))})
         else:
