@@ -69,11 +69,16 @@ class ListenQueue(threading.Thread):
 
     def __init__(self, helper, config: dict, callback):
         threading.Thread.__init__(self)
+        self.pika_credentials = None
+        self.pika_parameters = None
         self.pika_connection = None
         self.channel = None
         self.helper = helper
         self.callback = callback
-        self.uri = config["uri"]
+        self.host = config["connection"]["host"]
+        self.port = config["connection"]["port"]
+        self.user = config["connection"]["user"]
+        self.password = config["connection"]["pass"]
         self.queue_name = config["listen"]
 
     # noinspection PyUnusedLocal
@@ -129,9 +134,11 @@ class ListenQueue(threading.Thread):
         while True:
             try:
                 # Connect the broker
-                self.pika_connection = pika.BlockingConnection(
-                    pika.URLParameters(self.uri)
+                self.pika_credentials = pika.PlainCredentials(self.user, self.password)
+                self.pika_parameters = pika.ConnectionParameters(
+                    self.host, self.port, "/", self.pika_credentials
                 )
+                self.pika_connection = pika.BlockingConnection(self.pika_parameters)
                 self.channel = self.pika_connection.channel()
                 self.channel.basic_consume(
                     queue=self.queue_name, on_message_callback=self._process_message
@@ -210,18 +217,21 @@ class StreamCatcher(threading.Thread):
         r = requests.post(
             self.opencti_url + "/stream/history", json=payload, headers=headers
         )
-        return r.json()["lastEventId"]
+        result = r.json()
+        if result and "lastEventId" in result:
+            return result["lastEventId"]
 
     def run(self):
-        from_event_id = self.connector_last_event_id
-        from_event_timestamp = 0
-        last_event_timestamp = int(self.last_event_id.split("-")[0])
-        while (
-            from_event_timestamp <= last_event_timestamp
-            and from_event_id != self.last_event_id
-        ):
-            from_event_id = self.get_range(from_event_id)
-            from_event_timestamp = int(from_event_id.split("-")[0])
+        if self.connector_last_event_id:
+            from_event_id = self.connector_last_event_id
+            from_event_timestamp = 0
+            last_event_timestamp = int(self.last_event_id.split("-")[0])
+            while (
+                from_event_timestamp <= last_event_timestamp
+                and from_event_id != self.last_event_id
+            ):
+                from_event_id = self.get_range(from_event_id)
+                from_event_timestamp = int(from_event_id.split("-")[0])
         logging.info("Events catchup requests done.")
 
 
@@ -489,8 +499,6 @@ class OpenCTIConnectorHelper:
         :type entities_types: list, optional
         :param update: whether to updated data in the database, defaults to False
         :type update: bool, optional
-        :param split: whether to split the stix bundle before processing, defaults to True
-        :type split: bool, optional
         :raises ValueError: if the bundle is empty
         :return: list of bundles
         :rtype: list
@@ -498,42 +506,37 @@ class OpenCTIConnectorHelper:
         work_id = kwargs.get("work_id", self.work_id)
         entities_types = kwargs.get("entities_types", None)
         update = kwargs.get("update", False)
-        split = kwargs.get("split", True)
 
         if entities_types is None:
             entities_types = []
-        if split:
-            stix2_splitter = OpenCTIStix2Splitter()
-            bundles = stix2_splitter.split_bundle(bundle)
-            if len(bundles) == 0:
-                raise ValueError("Nothing to import")
-            if work_id is not None:
-                self.api.work.add_expectations(work_id, len(bundles))
-            pika_connection = pika.BlockingConnection(
-                pika.URLParameters(self.config["uri"])
-            )
-            channel = pika_connection.channel()
-            for sequence, bundle in enumerate(bundles, start=1):
-                self._send_bundle(
-                    channel,
-                    bundle,
-                    work_id=work_id,
-                    entities_types=entities_types,
-                    sequence=sequence,
-                    update=update,
-                )
-            channel.close()
-            return bundles
-        else:
-            pika_connection = pika.BlockingConnection(
-                pika.URLParameters(self.config["uri"])
-            )
-            channel = pika_connection.channel()
+        stix2_splitter = OpenCTIStix2Splitter()
+        bundles = stix2_splitter.split_bundle(bundle)
+        if len(bundles) == 0:
+            raise ValueError("Nothing to import")
+        if work_id is not None:
+            self.api.work.add_expectations(work_id, len(bundles))
+        pika_credentials = pika.PlainCredentials(
+            self.config["connection"]["user"], self.config["connection"]["pass"]
+        )
+        pika_parameters = pika.ConnectionParameters(
+            self.config["connection"]["host"],
+            self.config["connection"]["port"],
+            "/",
+            pika_credentials,
+        )
+        pika_connection = pika.BlockingConnection(pika_parameters)
+        channel = pika_connection.channel()
+        for sequence, bundle in enumerate(bundles, start=1):
             self._send_bundle(
-                channel, bundle, entities_types=entities_types, update=update
+                channel,
+                bundle,
+                work_id=work_id,
+                entities_types=entities_types,
+                sequence=sequence,
+                update=update,
             )
-            channel.close()
-            return [bundle]
+        channel.close()
+        return bundles
 
     def _send_bundle(self, channel, bundle, **kwargs) -> None:
         """send a STIX2 bundle to RabbitMQ to be consumed by workers
