@@ -149,7 +149,8 @@ class StixCyberObservable:
                 ctime
                 mtime
                 atime
-                 hashes {
+                x_opencti_additional_names
+                hashes {
                   algorithm
                   hash
                 }           
@@ -160,6 +161,10 @@ class StixCyberObservable:
                 serial_number
                 signature_algorithm
                 issuer
+                subject
+                subject_public_key_algorithm
+                subject_public_key_modulus
+                subject_public_key_exponent
                 validity_not_before
                 validity_not_after
                 hashes {
@@ -734,6 +739,11 @@ class StixCyberObservable:
                     "atime": observable_data["atime"]
                     if "atime" in observable_data
                     else None,
+                    "x_opencti_additional_names": observable_data[
+                        "x_opencti_additional_names"
+                    ]
+                    if "x_opencti_additional_names" in observable_data
+                    else None,
                 }
             elif type == "X509-Certificate":
                 input_variables["X509Certificate"] = {
