@@ -129,16 +129,52 @@ class StixDomainObject:
                 attribute_abstract
                 content
                 authors
+                objects {
+                    edges {
+                        node {
+                            ... on BasicObject {
+                                id
+                            }
+                            ... on BasicRelationship {
+                                id
+                            } 
+                        }
+                    }
+                }                
             }
             ... on ObservedData {
                 first_observed
                 last_observed
                 number_observed
+                objects {
+                    edges {
+                        node {
+                            ... on BasicObject {
+                                id
+                            }
+                            ... on BasicRelationship {
+                                id
+                            } 
+                        }
+                    }
+                }                
             }
             ... on Opinion {
                 explanation
                 authors
                 opinion
+                objects {
+                    edges {
+                        node {
+                            ... on BasicObject {
+                                id
+                            }
+                            ... on BasicRelationship {
+                                id
+                            } 
+                        }
+                    }
+                }                
             }
             ... on Report {
                 name
@@ -146,6 +182,18 @@ class StixDomainObject:
                 report_types
                 published
                 x_opencti_report_status
+                objects {
+                    edges {
+                        node {
+                            ... on BasicObject {
+                                id
+                            }
+                            ... on BasicRelationship {
+                                id
+                            } 
+                        }
+                    }
+                }
             }
             ... on CourseOfAction {
                 name
@@ -626,7 +674,10 @@ class StixDomainObject:
                  """
                 if data is None:
                     data = open(file_name, "rb")
-                    mime_type = magic.from_file(file_name, mime=True)
+                    if file_name.endswith(".json"):
+                        mime_type = "application/json"
+                    else:
+                        mime_type = magic.from_file(file_name, mime=True)
 
                 return self.opencti.query(
                     query,
